pub struct Runtime(/* private fields */);Expand description
A type-erased RuntimeTrait implementation. Think of this as an Arc<dyn RuntimeTrait>
Implementations
Sourceimpl Runtime
impl Runtime
Sourcepub fn new(runtime: impl RuntimeTrait) -> Runtime
pub fn new(runtime: impl RuntimeTrait) -> Runtime
Construct a new type-erased runtime object from any RuntimeTrait implementation.
Sourcepub fn spawn<Output>(
&self,
fut: impl Future<Output = Output> + Send + 'static,
) -> DroppableFuture<Pin<Box<dyn Future<Output = Option<Output>> + Send>>>where
Output: Send + 'static,
pub fn spawn<Output>(
&self,
fut: impl Future<Output = Output> + Send + 'static,
) -> DroppableFuture<Pin<Box<dyn Future<Output = Option<Output>> + Send>>>where
Output: Send + 'static,
Spawn a future on the runtime, returning a future that has detach-on-drop semantics
Spawned tasks conform to the following behavior:
-
detach on drop: If the returned
DroppableFutureis dropped immediately, the task will continue to execute until completion. -
unwinding: If the spawned future panics, this must not propagate to the join handle. Instead, the awaiting the join handle returns None in case of panic.
Sourcepub fn interval(&self, period: Duration) -> impl Stream<Item = ()> + Send
pub fn interval(&self, period: Duration) -> impl Stream<Item = ()> + Send
Returns a Stream that yields a () on the provided period