pub struct RuntimelessRuntime(/* private fields */);Expand description
a runtime that isn’t a runtime
Implementations
Sourceimpl RuntimelessRuntime
impl RuntimelessRuntime
Sourcepub fn spawn<Fut>(
&self,
fut: Fut,
) -> DroppableFuture<impl Future<Output = Option<Fut::Output>> + Send + 'static + use<Fut>>
pub fn spawn<Fut>( &self, fut: Fut, ) -> DroppableFuture<impl Future<Output = Option<Fut::Output>> + Send + 'static + use<Fut>>
Spawn a future on the runtime, returning a future that has detach-on-drop semantics
Spawned tasks conform to the following behavior:
-
detach on drop: If the returned
DroppableFutureis dropped immediately, the task will continue to execute until completion. -
unwinding: If the spawned future panics, this must not propagate to the join handle. Instead, the awaiting the join handle returns None in case of panic.
Sourcepub fn interval(
&self,
period: Duration,
) -> impl Stream<Item = ()> + Send + 'static + use<>
pub fn interval( &self, period: Duration, ) -> impl Stream<Item = ()> + Send + 'static + use<>
Returns a Stream that yields a () on the provided period