ServerConnector

Struct ServerConnector 

pub struct ServerConnector<H> { /* private fields */ }
a bridge between trillium servers and clients

Implementations

Source

impl<H> ServerConnector<H>

pub fn handler(&self) -> &Arc<H>

Borrows the handler

pub fn runtime(&self) -> &Runtime

Borrows the runtime

pub fn set_runtime(&mut self, runtime: impl Into<Runtime>) -> &mut Self

Sets the runtime, returning &mut Self for chaining

pub fn with_runtime(self, runtime: impl Into<Runtime>) -> Self

Owned chainable setter for the runtime, returning Self

pub fn server_config(&self) -> &Arc<ServerConfig>

Borrows the server config

pub fn set_server_config( &mut self, server_config: impl Into<Arc<ServerConfig>>, ) -> &mut Self

Sets the server config, returning &mut Self for chaining

pub fn with_server_config( self, server_config: impl Into<Arc<ServerConfig>>, ) -> Self

Owned chainable setter for the server config, returning Self

Source

impl<H: Handler> ServerConnector<H>

pub fn new(handler: H) -> Self

builds a new ServerConnector

pub async fn connect(&self, secure: bool) -> TestTransport

opens a new connection to this virtual server, returning the client transport