pub struct TestTransport { /* private fields */ }Expand description
a readable and writable transport for testing
Implementations
Sourceimpl TestTransport
impl TestTransport
Sourcepub fn write_side(&self) -> &CloseableCursor
pub fn write_side(&self) -> &CloseableCursor
Borrows the write side of this transport
Sourcepub fn set_peer_ip(&mut self, peer_ip: IpAddr) -> &mut Self
pub fn set_peer_ip(&mut self, peer_ip: IpAddr) -> &mut Self
Sets peer ip for the read side, returning &mut Self for chaining
Sourceimpl TestTransport
impl TestTransport
Sourcepub fn new() -> (TestTransport, TestTransport)
pub fn new() -> (TestTransport, TestTransport)
constructs a new test transport pair, representing two ends of a connection. either of them can be written to, and the content will be readable from the other. either of them can also be closed.
Sourcepub fn shutdown(&self, how: Shutdown)
pub fn shutdown(&self, how: Shutdown)
Shuts down the read, write, or both halves of this connection.
Sourcepub fn write_all(&self, bytes: impl AsRef<[u8]>)
pub fn write_all(&self, bytes: impl AsRef<[u8]>)
synchronously append the supplied bytes to the write side of this transport, notifying the read side of the other end
Sourcepub async fn read_available(&self) -> Vec<u8> ⓘ
pub async fn read_available(&self) -> Vec<u8> ⓘ
waits until there is content and then reads that content to a vec until there is no further content immediately available
Sourcepub async fn read_available_string(&self) -> String
pub async fn read_available_string(&self) -> String
waits until there is content and then reads that content to a string until there is no further content immediately available